@@ -17,8 +17,9 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
-from ._message import Message, encode_amqp
+from ._message import MessageCtx, encode_amqp, set_message_ctx, \
+    get_message_ctx
 
-__all__ = ['Message', 'encode_amqp']
+__all__ = ['MessageCtx', 'encode_amqp', 'set_message_ctx', 'get_message_ctx']
 
 # vim: sw=4:et:ai
