@@ -31,7 +31,7 @@ import logging
 import os
 import platform
 import typing as tp
-from collections.abc import AsyncIterator, Coroutine, AsyncGenerator
+from collections.abc import AsyncIterator, Coroutine
 from contextlib import asynccontextmanager
 from functools import partial
 from urllib.parse import urlparse
@@ -467,15 +467,15 @@ def connection(
 
 @tp.overload
 def connection(
-        coro: tp.Callable[P, AsyncGenerator[T, S]]
-    ) -> tp.Callable[P, AsyncGenerator[T, S]]:
+        coro: tp.Callable[P, AsyncIterator[T]]
+    ) -> tp.Callable[P, AsyncIterator[T]]:
     ...
 
 def connection(
         coro: tp.Callable[P, Coroutine[V, S, T]]
-           | tp.Callable[P, AsyncGenerator[T, S]]
+           | tp.Callable[P, AsyncIterator[T]]
 ) -> tp.Callable[P, Coroutine[V, S, T]] \
-     | tp.Callable[P, AsyncGenerator[T, S]]:
+     | tp.Callable[P, AsyncIterator[T]]:
     """
     Decorator to manage RabbitMQ Streams client connection.
 
@@ -487,7 +487,7 @@ def connection(
     :param coro: Coroutine using RabbitMQ Streams client.
     """
     f_coro = tp.cast(tp.Callable[P, Coroutine[V, S, T]], coro)
-    f_gen = tp.cast(tp.Callable[P, AsyncGenerator[T, S]], coro)
+    f_gen = tp.cast(tp.Callable[P, AsyncIterator[T]], coro)
     async def wrapper(*args: P.args, **kw: P.kwargs) -> T:
         client = tp.cast(
             ConnectionManager[RabbitMQStreamsProtocol], args[0]
@@ -498,7 +498,7 @@ def connection(
             await client.disconnect()
         return result
 
-    async def wrapper_gen(*args: P.args, **kw: P.kwargs) -> AsyncGenerator[T, S]:
+    async def wrapper_gen(*args: P.args, **kw: P.kwargs) -> AsyncIterator[T]:
         client = tp.cast(
             ConnectionManager[RabbitMQStreamsProtocol], args[0]
         )
@@ -508,6 +508,8 @@ def connection(
         finally:
             await client.disconnect()
 
+    # TODO: this does not work with async generators, which can receive a
+    # value with `asend`
     if inspect.iscoroutinefunction(coro):
         return wrapper
     elif inspect.isasyncgenfunction(coro):
