@@ -23,8 +23,8 @@ Basic types for RabbitMQ Streams API.
 
 from collections import deque
 
-from ..amqp import Message
+from ..amqp import MessageCtx
 
-MessageQueue = deque[Message]
+MessageQueue = deque[MessageCtx]
 
 # vim: sw=4:et:ai
