@@ -21,15 +21,18 @@
 Unit tests for creating RabbitMQ Streams client.
 """
 
+import asyncio
 import copy
 import inspect
 import typing as tp
+from collections.abc import AsyncIterator, AsyncGenerator
 from functools import partial
 
 from rbfly.error import RbFlyError
-from rbfly.streams.client import Scheme, streams_client, connection
-from rbfly.streams._client import PublisherTrait, Publisher, PublisherBatch, PublisherBin, \
-    PublisherBinBatch
+from rbfly.streams.client import Scheme, StreamsClient, streams_client, \
+    connection
+from rbfly.streams._client import PublisherTrait, Publisher, PublisherBatch, \
+    PublisherBin, PublisherBinBatch
 from rbfly.streams.offset import Offset, OffsetType
 from rbfly.streams.protocol import ProtocolError
 
@@ -79,6 +82,8 @@ def test_create_client(
     """
     Test creating RabbitMQ Streams client from URI.
     """
+    # pylint: disable=protected-access
+
     client = streams_client(uri)
     assert client._cinfo.scheme == scheme
     assert client._cinfo.host == host
@@ -93,6 +98,8 @@ async def test_get_offset_reference() -> None:
     Test getting offset specification for RabbitMQ stream with offset
     reference.
     """
+    # pylint: disable=protected-access
+
     client = streams_client('rabbitmq-stream://')
     protocol = mock.MagicMock()
     client.get_protocol = mock.AsyncMock(return_value=protocol)  # type: ignore
@@ -111,6 +118,8 @@ async def test_get_offset_reference_zero() -> None:
     Test getting offset specification for RabbitMQ stream with offset
     reference, when reference is not stored yet.
     """
+    # pylint: disable=protected-access
+
     client = streams_client('rabbitmq-stream://')
     protocol = mock.MagicMock()
     client.get_protocol = mock.AsyncMock(return_value=protocol)  # type: ignore
@@ -129,6 +138,8 @@ async def test_get_offset() -> None:
     Test getting offset specification for RabbitMQ stream using offset
     value (not using offset reference).
     """
+    # pylint: disable=protected-access
+
     client = streams_client('rabbitmq-stream://')
     protocol = mock.MagicMock()
     client.get_protocol = mock.AsyncMock(return_value=protocol)  # type: ignore
@@ -239,16 +250,51 @@ def test_connection_coroutine() -> None:
     assert inspect.iscoroutinefunction(connection(f))
     assert inspect.iscoroutinefunction(connection(partial(f)))
 
-def test_connection_async_generator() -> None:
+@pytest.mark.asyncio
+async def test_connection_async_iterator() -> None:
     """
-    Test if connection decorator returns asynchronous genenerator function.
+    Test if connection decorator returns asynchronous iterator function.
     """
-    async def f():  # type: ignore
-        while True:
-            yield 1
+    async def fx(client: StreamsClient) -> AsyncIterator[int]:
+        for i in range(10):
+            yield i
+            await asyncio.sleep(0.001)
 
-    assert inspect.isasyncgenfunction(connection(f))
-    assert inspect.isasyncgenfunction(connection(partial(f)))
+    assert inspect.isasyncgenfunction(connection(fx))
+    assert inspect.isasyncgenfunction(connection(partial(fx)))
+
+    client = mock.AsyncMock()
+    coro = connection(fx)(client)
+    result = [v async for v in coro]
+    assert result == list(range(10))
+    client.disconnect.assert_called_once()
+
+# TODO: make connection decorator work with generators receiving data via
+# yield
+@pytest.mark.skip
+@pytest.mark.asyncio
+async def test_connection_async_generator_yield() -> None:
+    @connection
+    async def fx(client: StreamsClient, data: list[int]) -> AsyncGenerator[None, int]:
+        while True:
+            value = yield
+            data.append(value)
+            await asyncio.sleep(0.1)
+
+    assert inspect.isasyncgenfunction(fx)
+
+    client = mock.AsyncMock()
+    data: list[int] = []
+
+    f = fx(client, data)
+    await f.asend(None)  # type: ignore
+    await f.asend(1)     # type: ignore
+    await f.asend(2)     # type: ignore
+    await f.asend(3)     # type: ignore
+    await f.aclose()     # type: ignore
+
+    assert data == [1, 2, 3]
+    client.disconnect.assert_called_once()
 
 def test_connection_invalid() -> None:
     """
